"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .remote_pb2 import *
class RemoteExecutorStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    RemoteCall:grpc.UnaryUnaryMultiCallable[
        global___RemoteCallRequest,
        global___RemoteCallResponse] = ...

    LaunchJob:grpc.UnaryUnaryMultiCallable[
        global___LaunchJobRequest,
        global___LaunchJobResponse] = ...

    LaunchBlockingJob:grpc.UnaryUnaryMultiCallable[
        global___LaunchBlockingJobRequest,
        global___LaunchBlockingJobResponse] = ...

    PostResult:grpc.UnaryUnaryMultiCallable[
        global___PostResultRequest,
        global___PostResultResponse] = ...


class RemoteExecutorServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def RemoteCall(self,
        request: global___RemoteCallRequest,
        context: grpc.ServicerContext,
    ) -> global___RemoteCallResponse: ...

    @abc.abstractmethod
    def LaunchJob(self,
        request: global___LaunchJobRequest,
        context: grpc.ServicerContext,
    ) -> global___LaunchJobResponse: ...

    @abc.abstractmethod
    def LaunchBlockingJob(self,
        request: global___LaunchBlockingJobRequest,
        context: grpc.ServicerContext,
    ) -> global___LaunchBlockingJobResponse: ...

    @abc.abstractmethod
    def PostResult(self,
        request: global___PostResultRequest,
        context: grpc.ServicerContext,
    ) -> global___PostResultResponse: ...


def add_RemoteExecutorServicer_to_server(servicer: RemoteExecutorServicer, server: grpc.Server) -> None: ...
